Project Scope
-------------

The goal of :code:`GWPopulation` is to provide a flexible and extensible framework for population inference with gravitational-wave data,
not to provide an exhaustive set of possible models.

As such, we are happy to accept contributions that add new methods to calculate likelihoods, or additional flexibility,
but we are unlikely to accept contributions that add new models to the core package.

We are happy though to add links to external repositories that provide new models to the documentation, especially in the examples section.